@@ -2254,8 +2254,9 @@ void CMD_CursorMove(F_CMD_ARGS)
 	{
 		y = pan_y;
 	}
-	FWarpPointer(dpy, None, Scr.Root, 0, 0, Scr.MyDisplayWidth,
-		     Scr.MyDisplayHeight, x, y);
+	FWarpPointerUpdateEvpos(
+		exc->x.elast, dpy, None, Scr.Root, 0, 0, Scr.MyDisplayWidth,
+		Scr.MyDisplayHeight, x, y);
 
 	return;
 }
@@ -2768,7 +2769,6 @@ void CMD_ModulePath(F_CMD_ARGS)
 	return;
 }
 
-
 void CMD_ModuleTimeout(F_CMD_ARGS)
 {
 	int timeout;
