@@ -129,7 +129,7 @@ void GetMwmHints(FvwmWindow *t)
 		t->mwm_hints = NULL;
 	}
 	if (XGetWindowProperty(
-		    dpy, FW_W(t), _XA_MwmAtom, 0L, 32, False,
+		    dpy, FW_W(t), _XA_MwmAtom, 0L, 32L, False,
 		    _XA_MwmAtom, &actual_type, &actual_format, &nitems,
 		    &bytesafter,(unsigned char **)&t->mwm_hints)==Success)
 	{
@@ -183,7 +183,7 @@ void GetOlHints(FvwmWindow *t)
 	t->ol_hints = OL_DECOR_ALL;
 
 	if (XGetWindowProperty(
-		    dpy, FW_W(t), _XA_OL_WIN_ATTR, 0L, 32, False,
+		    dpy, FW_W(t), _XA_OL_WIN_ATTR, 0L, 32L, False,
 		    _XA_OL_WIN_ATTR, &actual_type, &actual_format,
 		    &nitems, &bytesafter, (unsigned char **)&hints) == Success)
 	{
@@ -243,7 +243,7 @@ void GetOlHints(FvwmWindow *t)
 	}
 
 	if (XGetWindowProperty(
-		    dpy, FW_W(t), _XA_OL_DECOR_ADD, 0L, 32, False,
+		    dpy, FW_W(t), _XA_OL_DECOR_ADD, 0L, 32L, False,
 		    XA_ATOM, &actual_type, &actual_format, &nitems,
 		    &bytesafter,(unsigned char **)&hints)==Success)
 	{
@@ -274,7 +274,7 @@ void GetOlHints(FvwmWindow *t)
 	}
 
 	if (XGetWindowProperty(
-		    dpy, FW_W(t), _XA_OL_DECOR_DEL, 0L, 32, False,
+		    dpy, FW_W(t), _XA_OL_DECOR_DEL, 0L, 32L, False,
 		    XA_ATOM, &actual_type, &actual_format, &nitems,
 		    &bytesafter,(unsigned char **)&hints)==Success)
 	{
@@ -614,7 +614,7 @@ void SelectDecor(FvwmWindow *t, window_style *pstyle, short *buttons)
 	return;
 }
 
-static Bool __is_resize_allowed(FvwmWindow *t, int functions,
+static Bool __is_resize_allowed(const FvwmWindow *t, int functions,
 				Bool is_user_request)
 {
         if (!HAS_OVERRIDE_SIZE_HINTS(t) &&
@@ -644,8 +644,8 @@ static Bool __is_resize_allowed(FvwmWindow *t, int functions,
 ** combined them here and made them wrapper functions instead.
 */
 Bool is_function_allowed(
-	int function, char *action_string, FvwmWindow *t, Bool is_user_request,
-	Bool do_allow_override_mwm_hints)
+	int function, char *action_string, const FvwmWindow *t,
+	Bool is_user_request, Bool do_allow_override_mwm_hints)
 {
 	unsigned int functions;
 	char *functionlist[] = {
