@@ -394,7 +394,7 @@ void *atom_get(Window win, Atom to_get, Atom type, unsigned int *size)
 	retval = NULL;
 	length = 0x7fffffff;
 	ok = XGetWindowProperty(
-		dpy, win, to_get, 0, length, False, type, &type_ret,
+		dpy, win, to_get, 0L, length, False, type, &type_ret,
 		&format_ret, &num_ret, &bytes_after, &retval);
 
 	if ((ok == Success) && (retval) && (num_ret > 0) && (format_ret > 0))
@@ -1346,10 +1346,10 @@ int ewmh_HandleDesktop(EWMH_CMD_ARGS)
 	FPS_GRAB_FOCUS(S_FOCUS_POLICY(SCC(*style)), 1);
 
 	/* ClickToFocusPassesClick */
-	FPS_PASS_FOCUS_CLICK(S_FOCUS_POLICY(SCF(*style)), 0);
+	FPS_PASS_FOCUS_CLICK(S_FOCUS_POLICY(SCF(*style)), 1);
 	FPS_PASS_FOCUS_CLICK(S_FOCUS_POLICY(SCM(*style)), 1);
 	FPS_PASS_FOCUS_CLICK(S_FOCUS_POLICY(SCC(*style)), 1);
-	FPS_PASS_RAISE_CLICK(S_FOCUS_POLICY(SCF(*style)), 0);
+	FPS_PASS_RAISE_CLICK(S_FOCUS_POLICY(SCF(*style)), 1);
 	FPS_PASS_RAISE_CLICK(S_FOCUS_POLICY(SCM(*style)), 1);
 	FPS_PASS_RAISE_CLICK(S_FOCUS_POLICY(SCC(*style)), 1);
 
@@ -1930,8 +1930,7 @@ void EWMH_fullscreen(FvwmWindow *fw)
 		new_layer(fw, Scr.TopLayer);
 		if (sl == 0)
 		{
-			fw->ewmh_normal_layer =
-				Scr.DefaultLayer;
+			fw->ewmh_normal_layer = Scr.DefaultLayer;
 		}
 		else
 		{
