@@ -1885,8 +1885,8 @@ int main(int argc, char **argv)
 			/* obsolete option */
 			fvwm_msg(
 				WARN, "main",
-				"The -blackout option is obsolete, it may be "
-				"removed in the future.");
+				"The -blackout option is obsolete, it will be "
+				"removed in 3.0.");
 		}
 		else if (strcmp(argv[i], "-r") == 0 ||
 			 strcmp(argv[i], "-replace") == 0 ||
@@ -2042,7 +2042,7 @@ int main(int argc, char **argv)
 		if (dn == NULL)
 		{
 			fvwm_msg(
-				ERR, "main", "Cannot found default display (%s)",
+				ERR, "main", "couldn't find default display (%s)",
 				XDisplayName(dn));
 		}
 		else
@@ -2359,13 +2359,21 @@ int main(int argc, char **argv)
 	}
 
 	SetupICCCM2(replace_wm);
-	XSetErrorHandler(CatchRedirectError);
 	XSetIOErrorHandler(CatchFatal);
-	XSelectInput(dpy, Scr.Root, XEVMASK_ROOTW);
-	XFlush(dpy);
-
-	XSetErrorHandler(FvwmErrorHandler);
-
+	{
+		/* We need to catch any errors of XSelectInput on the root
+		 * window here.  The event mask contains
+		 * SubstructureRedirectMask which can be acquired by exactly
+		 * one client (window manager).  Synchronizing is necessary
+		 * here because Neither XSetErrorHandler nor XSelectInput
+		 * generate any protocol requests.
+		 */
+		XSync(dpy, 0);
+		XSetErrorHandler(CatchRedirectError);
+		XSelectInput(dpy, Scr.Root, XEVMASK_ROOTW);
+		XSync(dpy, 0);
+		XSetErrorHandler(FvwmErrorHandler);
+	}
 	{
 		/* do not grab the pointer earlier because if fvwm exits with
 		 * the pointer grabbed while a different display is visible,
