@@ -48,11 +48,6 @@
 #define WithdrawnState 0
 #endif
 
-#ifndef TRUE
-#define TRUE    1
-#define FALSE   0
-#endif
-
 /* ---------------------------- global macros ------------------------------ */
 
 /*
@@ -400,6 +395,20 @@ typedef struct
 	unsigned has_ewmh_init_wm_desktop : 2;
 } window_flags;
 
+
+/* Actions allowed by modules. */
+typedef struct action_flags
+{
+	unsigned is_movable : 1;
+	unsigned is_deletable : 1;
+	unsigned is_destroyable : 1;
+	unsigned is_closable : 1;
+	unsigned is_maximizable : 1;
+	unsigned is_resizable : 1;
+	unsigned is_iconifiable : 1;
+} action_flags;
+
+
 /* Window name data structure for window conditions: a list of lists
    of names to match, the boolean operation on the matches being an
    AND of ORs. */
@@ -640,7 +649,7 @@ typedef struct FvwmWindow
 	FlocaleNameString icon_name;
 	char *visible_name;
 	char *visible_icon_name;
-	/* if non-null: Use this instead of any other names for matching 
+	/* if non-null: Use this instead of any other names for matching
 	   styles */
 	char *style_name;
 	int name_count;
