@@ -108,7 +108,9 @@ typedef struct
 	MenuDimensions *dim;
 	FvwmWindow *fw;
 	XEvent *ev;
+	unsigned int used_mini_icons;
 	struct MenuRoot *cb_mr;
+	/* number of item labels present in the item format */
 	Bool (*cb_reset_bg)(struct MenuRoot *mr, XEvent *pevent);
 	struct
 	{
@@ -125,7 +127,7 @@ MenuItem *menuitem_clone(MenuItem *mi);
 MenuItem *menuitem_create(void);
 void menuitem_free(MenuItem *mi);
 void menuitem_get_size(
-	MenuItem *mi, MenuItemPartSizesT *mips, FlocaleFont *font,
+	MenuItem *mi, MenuItemPartSizesT *mipst, FlocaleFont *font,
 	Bool do_reverse_icon_order);
 void menuitem_paint(
 	MenuItem *mi, MenuPaintItemParameters *mpip);
