@@ -1068,6 +1068,51 @@ static Bool __place_get_wm_pos(
 			fw, sflags, &screen_g, &xl, &yt, pdeltax, pdeltay, 0);
 		flags.is_smartly_placed = True;
 		break;
+	case PLACE_UNDERMOUSE:
+	{
+		int mx;
+		int my;
+
+		if (
+			FQueryPointer(
+				dpy, Scr.Root, &JunkRoot, &JunkChild, &mx, &my,
+				&JunkX, &JunkY, &JunkMask) == False)
+		{
+			/* pointer is on a different screen */
+			xl = 0;
+			yt = 0;
+		}
+		else
+		{
+			xl = mx - (fw->frame_g.width / 2);
+			yt = my - (fw->frame_g.height / 2);
+			if (
+				xl + fw->frame_g.width >
+				screen_g.x + screen_g.width)
+			{
+				xl = screen_g.x + screen_g.width -
+					fw->frame_g.width;
+			}
+			if (
+				yt + fw->frame_g.height >
+				screen_g.y + screen_g.height)
+			{
+				yt = screen_g.y + screen_g.height -
+					fw->frame_g.height;
+			}
+			if (xl < screen_g.x)
+			{
+				xl = screen_g.x;
+			}
+			if (yt < screen_g.y)
+			{
+				yt = screen_g.y;
+			}
+		}
+		attr_g->x = xl;
+		attr_g->y = yt;
+		break;
+	}
 	default:
 		/* can't happen */
 		break;
@@ -1631,7 +1676,10 @@ static void __explain_placement(FvwmWindow *fw, placement_reason_t *reason)
 	s = explanation;
 	strcat(s, "placed new window 0x%x '%s':\n");
 	s += strlen(s);
-	/* desk */
+	sprintf(
+		s, "  initial size %dx%d\n", fw->frame_g.width,
+		fw->frame_g.height);
+	s += strlen(s);
 	switch (reason->desk.reason)
 	{
 	case PR_DESK_CURRENT:
@@ -1827,6 +1875,9 @@ static void __explain_placement(FvwmWindow *fw, placement_reason_t *reason)
 		case PLACE_MINOVERLAP:
 			a = "MinOverlap";
 			break;
+		case PLACE_UNDERMOUSE:
+			a = "UnderMouse";
+			break;
 		default:
 			a = "bug";
 			break;
