@@ -53,7 +53,7 @@ static int push_read_file(const char *file)
 		fvwm_msg(
 			ERR, "Read", "Nested Read limit %d is reached",
 			MAX_READ_DEPTH);
-		return FALSE;
+		return 0;
 	}
 	prev_read_files[curr_read_depth++] = curr_read_file;
 	curr_read_file = safestrdup(file);
@@ -63,7 +63,7 @@ static int push_read_file(const char *file)
 	}
 	curr_read_dir = NULL;
 
-	return TRUE;
+	return 1;
 }
 
 static void pop_read_file(void)
@@ -196,7 +196,7 @@ static int parse_filename(
 
 
 /**
- * Returns FALSE if file not found
+ * Returns 0 if file not found
  **/
 int run_command_file(
 	char *filename, const exec_context_t *exc)
@@ -222,17 +222,17 @@ int run_command_file(
 	}
 	if (f == NULL)
 	{
-		return FALSE;
+		return 0;
 	}
-	if (push_read_file(full_filename) == FALSE)
+	if (push_read_file(full_filename) == 0)
 	{
-		return FALSE;
+		return 0;
 	}
 	run_command_stream(NULL, f, exc);
 	fclose(f);
 	pop_read_file();
 
-	return TRUE;
+	return 1;
 }
 
 /**
