@@ -1,3 +1,4 @@
+/* -*-c-*- */
 #ifndef FVWM_READ_H
 #define FVWM_READ_H
 
@@ -14,16 +15,17 @@ extern const char *get_current_read_dir(void);
  *
  * Parameters eventp, fw, context, and Module supply the context
  * for executing the commands.
- * fvwm_cond_func_rc is passed thru incase piperead is running in a function.
+ * cond_rc_t is passed thru incase piperead is running in a function.
  **/
-void run_command_stream(fvwm_cond_func_rc *cond_rc, FILE *f, const exec_context_t *exc);
+void run_command_stream(
+	cond_rc_t *cond_rc, FILE *f, const exec_context_t *exc);
 
 
 /**
  * Given a filename, open it and execute the commands therein.
  *
  * If the filename is not an absolute path, search for it in
- * fvwm_userdir (set in main()) or in FVWM_DATADIR.  Return TRUE
+ * fvwm_userdir (set in main()) or in FVWM_DATADIR.  Return 1
  * if the file was found and executed.
  **/
 int run_command_file(char *filename, const exec_context_t *exc);
