@@ -42,6 +42,7 @@
 #include "icons.h"
 #include "gnome.h"
 #include "ewmh.h"
+#include "frame.h"
 
 /* ---------------------------- local definitions -------------------------- */
 
@@ -57,8 +58,6 @@
 
 /* ---------------------------- imports ------------------------------------ */
 
-extern Bool is_frame_hide_window();
-
 /* ---------------------------- included code files ------------------------ */
 
 /* ---------------------------- local types -------------------------------- */
@@ -107,11 +106,12 @@ static void dump_stack_ring(void)
 	}
 	XBell(dpy, 0);
 	fprintf(stderr,"dumping stack ring:\n");
-	for (t1 = Scr.FvwmRoot.stack_next; t1 != &Scr.FvwmRoot;
-	     t1 = t1->stack_next)
+	for (
+		t1 = Scr.FvwmRoot.stack_next; t1 != &Scr.FvwmRoot;
+		t1 = t1->stack_next)
 	{
-		fprintf(stderr,"    l=%d fw=0x%08x f=0x%08x '%s'\n", t1->layer,
-			(int)t1, (int)FW_W_FRAME(t1), t1->name.name);
+		fprintf(stderr,"    l=%d fw=%p f=0x%08x '%s'\n", t1->layer,
+			t1, (int)FW_W_FRAME(t1), t1->name.name);
 	}
 
 	return;
@@ -138,15 +138,16 @@ void verify_stack_ring_consistency(void)
 	}
 	last_layer = t2->layer;
 
-	for (t1 = t2->stack_next; t1 != &Scr.FvwmRoot;
-	     t2 = t1, t1 = t1->stack_next)
+	for (
+		t1 = t2->stack_next; t1 != &Scr.FvwmRoot;
+		t2 = t1, t1 = t1->stack_next)
 	{
 		if (t1->layer > last_layer)
 		{
 			fprintf(
 				stderr,
-				"vsrc: stack ring is corrupt! "
-				"'%s' (layer %d) is above '%s' (layer %d/%d)\n",
+				"vsrc: stack ring is corrupt! '%s' (layer %d)"
+				" is above '%s' (layer %d/%d)\n",
 				t1->name.name, t1->layer, t2->name.name,
 				t2->layer, last_layer);
 			dump_stack_ring();
@@ -155,8 +156,9 @@ void verify_stack_ring_consistency(void)
 		last_layer = t1->layer;
 	}
 	t2 = &Scr.FvwmRoot;
-	for (t1 = t2->stack_next; t1 != &Scr.FvwmRoot;
-	     t2 = t1, t1 = t1->stack_next)
+	for (
+		t1 = t2->stack_next; t1 != &Scr.FvwmRoot;
+		t2 = t1, t1 = t1->stack_next)
 	{
 		if (t1->stack_prev != t2)
 		{
@@ -168,9 +170,8 @@ void verify_stack_ring_consistency(void)
 		fprintf(
 			stderr,
 			"vsrc: stack ring is corrupt -"
-			" fvwm will probably crash! "
-			"0x%08x -> 0x%08x but 0x%08x <- 0x%08x\n",
-			(int)t2, (int)t1, (int)(t1->stack_prev), (int)t1);
+			" fvwm will probably crash! %p -> %p but %p <- %p",
+			t2, t1, t1->stack_prev, t1);
 		dump_stack_ring();
 		return;
 	}
@@ -182,11 +183,14 @@ void verify_stack_ring_consistency(void)
 	}
 
 	last_index = nchildren;
-	for (t1 = Scr.FvwmRoot.stack_next; t1 != &Scr.FvwmRoot;
-	     t1 = t1->stack_next)
+	for (
+		t1 = Scr.FvwmRoot.stack_next; t1 != &Scr.FvwmRoot;
+		t1 = t1->stack_next)
 	{
 		/* find window in window list */
-		for (i = 0; i < nchildren && FW_W_FRAME(t1) != children[i]; i++)
+		for (
+			i = 0; i < nchildren && FW_W_FRAME(t1) != children[i];
+			i++)
 		{
 			/* nothing to do here */
 		}
@@ -194,22 +198,24 @@ void verify_stack_ring_consistency(void)
 		{
 			fprintf(
 				stderr,"vsrc: window already died:"
-				" fw=0x%08x w=0x%08x '%s'\n",
-				(int)t1, (int)FW_W_FRAME(t1), t1->name.name);
+				" fw=%p w=0x%08x '%s'\n",
+				t1, (int)FW_W_FRAME(t1), t1->name.name);
 		}
 		else if (i >= last_index)
 		{
 			fprintf(
 				stderr, "vsrc: window is at wrong position"
-				" in stack ring: fw=0x%08x f=0x%08x '%s'\n",
-				(int)t1, (int)FW_W_FRAME(t1),
+				" in stack ring: fw=%p f=0x%08x '%s'\n",
+				t1, (int)FW_W_FRAME(t1),
 				t1->name.name);
 			dump_stack_ring();
 			fprintf(stderr,"dumping X stacking order:\n");
 			for (i = nchildren; i-- > 0; )
 			{
-				for (t1 = Scr.FvwmRoot.stack_next;
-				     t1 != &Scr.FvwmRoot; t1 = t1->stack_next)
+				for (
+					t1 = Scr.FvwmRoot.stack_next;
+					t1 != &Scr.FvwmRoot;
+					t1 = t1->stack_next)
 				{
 					/* only dump frame windows */
 					if (FW_W_FRAME(t1) == children[i])
@@ -242,6 +248,7 @@ static void add_windowlist_to_stack_ring_after(
 	list_head->stack_prev->stack_next = add_after_win->stack_next;
 	add_after_win->stack_next = list_head->stack_next;
 	list_head->stack_next->stack_prev = add_after_win;
+
 	return;
 }
 
@@ -254,7 +261,9 @@ static FvwmWindow *get_transientfor_top_fvwmwindow(FvwmWindow *t)
 	{
 		s = get_transientfor_fvwmwindow(s);
 		if (s)
+		{
 			t = s;
+		}
 	}
 
 	return t;
@@ -288,8 +297,9 @@ static void raise_over_unmanaged(FvwmWindow *t)
 	 */
 	if (!is_above_unmanaged(t, &OR_Above))
 	{
-		for (count = 0, t2 = Scr.FvwmRoot.stack_next;
-		     t2 != &Scr.FvwmRoot; t2 = t2->stack_next)
+		for (
+			count = 0, t2 = Scr.FvwmRoot.stack_next;
+			t2 != &Scr.FvwmRoot; t2 = t2->stack_next)
 		{
 			count++;
 			count += get_visible_icon_window_count(t2);
@@ -302,8 +312,9 @@ static void raise_over_unmanaged(FvwmWindow *t)
 		if (count > 0)
 		{
 			wins = (Window*) safemalloc (count * sizeof (Window));
-			for (i = 0, t2 = Scr.FvwmRoot.stack_next;
-			     t2 != &Scr.FvwmRoot; t2 = t2->stack_next)
+			for (
+				i = 0, t2 = Scr.FvwmRoot.stack_next;
+				t2 != &Scr.FvwmRoot; t2 = t2->stack_next)
 			{
 				wins[i++] = FW_W_FRAME(t2);
 				if (IS_ICONIFIED(t2) &&
@@ -377,9 +388,10 @@ static Bool __must_move_transients(
 		Bool scanning_above_window = True;
 		FvwmWindow *q;
 
-		for (q = Scr.FvwmRoot.stack_next;
-		     q != &Scr.FvwmRoot && t->layer <= q->layer;
-		     q = q->stack_next)
+		for (
+			q = Scr.FvwmRoot.stack_next;
+			q != &Scr.FvwmRoot && t->layer <= q->layer;
+			q = q->stack_next)
 		{
 			if (t->layer < q->layer)
 			{
@@ -455,8 +467,9 @@ static void __sort_transient_ring(FvwmWindow *ring)
 	 * performance hit.  Because it is important that the order of windows
 	 * with the same key is not changed, we can not just use qsort() here.
 	 */
-	for (t = ring->stack_next, prev = ring; t->stack_next != ring;
-	     prev = t->stack_prev)
+	for (
+		t = ring->stack_next, prev = ring; t->stack_next != ring;
+		prev = t->stack_prev)
 	{
 		s = t->stack_next;
 		if (t->scratch.i < s->scratch.i)
@@ -594,7 +607,9 @@ FvwmWindow *__get_window_to_insert_after(FvwmWindow *fw, stack_mode_t mode)
 		test_layer = fw->layer;
 		break;
 	}
-	for (s = Scr.FvwmRoot.stack_next; s != &Scr.FvwmRoot; s = s->stack_next)
+	for (
+		s = Scr.FvwmRoot.stack_next; s != &Scr.FvwmRoot;
+		s = s->stack_next)
 	{
 		if (s == fw)
 		{
@@ -686,8 +701,9 @@ static Bool __raise_lower_recursion(
 {
 	FvwmWindow *t2;
 
-	for (t2 = Scr.FvwmRoot.stack_next; t2 != &Scr.FvwmRoot;
-	     t2 = t2->stack_next)
+	for (
+		t2 = Scr.FvwmRoot.stack_next; t2 != &Scr.FvwmRoot;
+		t2 = t2->stack_next)
 	{
 		if (FW_W(t2) == FW_W_TRANSIENTFOR(t))
 		{
@@ -969,9 +985,9 @@ static void ResyncXStackingOrder(void)
 	if (count > 0)
 	{
 		wins = (Window *)safemalloc(3 * count * sizeof (Window));
-
-		for (i = 0, t = Scr.FvwmRoot.stack_next; count--;
-		     t = t->stack_next)
+		for (
+			i = 0, t = Scr.FvwmRoot.stack_next; count--;
+			t = t->stack_next)
 		{
 			wins[i++] = FW_W_FRAME(t);
 			if (IS_ICONIFIED(t) && !IS_ICON_SUPPRESSED(t))
@@ -1023,8 +1039,8 @@ static void BroadcastRestack(FvwmWindow *s1, FvwmWindow *s2)
 		}
 		/* s1 has been moved to the top of stack */
 		BroadcastPacket(
-			M_RAISE_WINDOW, 3, FW_W(s1), FW_W_FRAME(s1),
-			(unsigned long)s1);
+			M_RAISE_WINDOW, 3, (long)FW_W(s1),
+			(long)FW_W_FRAME(s1), (unsigned long)s1);
 		if (s1->stack_next == s2)
 		{
 			/* avoid sending empty RESTACK packet */
@@ -1037,8 +1053,9 @@ static void BroadcastRestack(FvwmWindow *s1, FvwmWindow *s2)
 		 */
 		return;
 	}
-	for (fw = s1, num = 1; fw != s2 && fw != &Scr.FvwmRoot;
-	     fw = fw->stack_next, num++)
+	for (
+		fw = s1, num = 1; fw != s2 && fw != &Scr.FvwmRoot;
+		fw = fw->stack_next, num++)
 	{
 		/* nothing */
 	}
@@ -1156,8 +1173,6 @@ static Bool is_above_unmanaged(FvwmWindow *fw, Window *umtop)
 	  Called from raise_over_unmanaged and is_on_top_of_layer.
 	*/
 	Bool ontop = True;
-
-
 	Window junk;
 	Window *tops;
 	int i;
@@ -1165,6 +1180,10 @@ static Bool is_above_unmanaged(FvwmWindow *fw, Window *umtop)
 	Window OR_Above = None;
 	XWindowAttributes wa;
 
+	if (fw->Desk != Scr.CurrentDesk)
+	{
+		return True;
+	}
 	if (!XQueryTree(dpy, Scr.Root, &junk, &junk, &tops, &num))
 	{
 		return ontop;
@@ -1193,8 +1212,7 @@ static Bool is_above_unmanaged(FvwmWindow *fw, Window *umtop)
 		if (wa.override_redirect == True
 		    && wa.class != InputOnly
 		    && tops[i] != Scr.NoFocusWin
-		    && (! is_frame_hide_window(tops[i]))
-			)
+		    && (!is_frame_hide_window(tops[i])))
 		{
 			OR_Above = tops[i];
 		}
@@ -1413,7 +1431,8 @@ Bool position_new_window_in_stack_ring(FvwmWindow *t, Bool do_lower)
 void RaiseWindow(FvwmWindow *t)
 {
 	BroadcastPacket(
-		M_RAISE_WINDOW, 3, FW_W(t), FW_W_FRAME(t), (unsigned long)t);
+		M_RAISE_WINDOW, 3, (long)FW_W(t), (long)FW_W_FRAME(t),
+		(unsigned long)t);
 	raise_or_lower_window(t, SM_RAISE, True, False);
 	focus_grab_buttons_on_layer(t->layer);
 #ifdef DEBUG_STACK_RING
@@ -1425,7 +1444,8 @@ void RaiseWindow(FvwmWindow *t)
 void LowerWindow(FvwmWindow *t)
 {
 	BroadcastPacket(
-		M_LOWER_WINDOW, 3, FW_W(t), FW_W_FRAME(t), (unsigned long)t);
+		M_LOWER_WINDOW, 3, (long)FW_W(t), (long)FW_W_FRAME(t),
+		(unsigned long)t);
 	raise_or_lower_window(t, SM_LOWER, True, False);
 	focus_grab_buttons_on_layer(t->layer);
 #ifdef DEBUG_STACK_RING
@@ -1449,15 +1469,16 @@ Bool HandleUnusualStackmodes(
 	unsigned int stack_mode, FvwmWindow *r, Window rw, FvwmWindow *s,
 	Window sw)
 {
-	Bool restack = 0;
+	int do_restack = 0;
 	FvwmWindow *t;
 
 	/*  DBUG("HandleUnusualStackmodes", "called with %d, %lx\n",
 	    stack_mode, s);*/
 
-	if (((rw != FW_W(r)) ^ IS_ICONIFIED(r)) ||
-	    (s && (((sw != FW_W(s)) ^ IS_ICONIFIED(s)) ||
-		   (r->Desk != s->Desk))))
+	if (
+		((rw != FW_W(r)) ^ IS_ICONIFIED(r)) ||
+		(s && (((sw != FW_W(s)) ^ IS_ICONIFIED(s)) ||
+		       (r->Desk != s->Desk))))
 	{
 		/* one of the relevant windows is unmapped */
 		return 0;
@@ -1466,37 +1487,40 @@ Bool HandleUnusualStackmodes(
 	switch (stack_mode)
 	{
 	case TopIf:
-		for (t = r->stack_prev; (t != &Scr.FvwmRoot) && !restack;
-		     t = t->stack_prev)
+		for (
+			t = r->stack_prev; t != &Scr.FvwmRoot && !do_restack;
+			t = t->stack_prev)
 		{
-			restack = (((s == NULL) || (s == t)) && overlap (t, r));
+			do_restack = ((s == NULL || s == t) && overlap(t, r));
 		}
-		if (restack)
+		if (do_restack)
 		{
 			RaiseWindow (r);
 		}
 		break;
 	case BottomIf:
-		for (t = r->stack_next; (t != &Scr.FvwmRoot) && !restack;
-		     t = t->stack_next)
+		for (
+			t = r->stack_next; t != &Scr.FvwmRoot && !do_restack;
+			t = t->stack_next)
 		{
-			restack = (((s == NULL) || (s == t)) && overlap (t, r));
+			do_restack = ((s == NULL || s == t) && overlap(t, r));
 		}
-		if (restack)
+		if (do_restack)
 		{
 			LowerWindow (r);
 		}
 		break;
 	case Opposite:
-		restack = (HandleUnusualStackmodes(TopIf, r, rw, s, sw) ||
-			   HandleUnusualStackmodes(BottomIf, r, rw, s, sw));
+		do_restack = (
+			HandleUnusualStackmodes(TopIf, r, rw, s, sw) ||
+			HandleUnusualStackmodes(BottomIf, r, rw, s, sw));
 		break;
 	}
-	/*  DBUG("HandleUnusualStackmodes", "\t---> %d\n", restack);*/
+	/*  DBUG("HandleUnusualStackmodes", "\t---> %d\n", do_restack);*/
 #ifdef DEBUG_STACK_RING
 	verify_stack_ring_consistency();
 #endif
-	return restack;
+	return do_restack;
 }
 
 /*
@@ -1564,8 +1588,10 @@ void mark_transient_subtree(
 		/* only work on the given layer */
 		start = &Scr.FvwmRoot;
 		end = &Scr.FvwmRoot;
-		for (s = Scr.FvwmRoot.stack_next;
-		     s != &Scr.FvwmRoot && s->layer >= layer; s = s->stack_next)
+		for (
+			s = Scr.FvwmRoot.stack_next;
+			s != &Scr.FvwmRoot && s->layer >= layer;
+			s = s->stack_next)
 		{
 			if (s == t)
 			{
@@ -1590,7 +1616,9 @@ void mark_transient_subtree(
 	}
 	/* clean the temporary flag in all windows and precalculate the
 	 * transient frame windows */
-	for (s = Scr.FvwmRoot.stack_next; s != &Scr.FvwmRoot; s = s->stack_next)
+	for (
+		s = Scr.FvwmRoot.stack_next; s != &Scr.FvwmRoot;
+		s = s->stack_next)
 	{
 		SET_IN_TRANSIENT_SUBTREE(s, 0);
 		if (IS_TRANSIENT(s) && (layer < 0 || layer == s->layer))
@@ -1680,6 +1708,10 @@ void new_layer(FvwmWindow *fw, int layer)
 	int old_layer;
 	Bool do_lower;
 
+	if (layer < 0)
+	{
+		layer = 0;
+	}
 	fw = get_transientfor_top_fvwmwindow(fw);
 	if (layer == fw->layer)
 	{
@@ -1696,7 +1728,6 @@ void new_layer(FvwmWindow *fw, int layer)
 		/* no windows to move */
 		return;
 	}
-
 	add_after_layer = layer;
 	if (layer < fw->layer)
 	{
@@ -1711,8 +1742,9 @@ void new_layer(FvwmWindow *fw, int layer)
 		do_lower = False;
 	}
 	/* find the place to insert the windows */
-	for (target = Scr.FvwmRoot.stack_next; target != &Scr.FvwmRoot;
-	     target = target->stack_next)
+	for (
+		target = Scr.FvwmRoot.stack_next; target != &Scr.FvwmRoot;
+		target = target->stack_next)
 	{
 		if (target->layer < add_after_layer)
 		{
@@ -1723,8 +1755,9 @@ void new_layer(FvwmWindow *fw, int layer)
 	/* insert windows at new position */
 	add_windowlist_to_stack_ring_after(&list_head, target->stack_prev);
 	prev = NULL;
-	for (s = list_head.stack_next; prev != list_head.stack_prev;
-	     prev = s, s = s->stack_next)
+	for (
+		s = list_head.stack_next; prev != list_head.stack_prev;
+		prev = s, s = s->stack_next)
 	{
 		s->layer = layer;
 		/* redraw title and buttons to update layer buttons */
@@ -1846,7 +1879,6 @@ void CMD_Layer(F_CMD_ARGS)
 		layer = 0;
 	}
 	new_layer(fw, layer);
-
 #ifdef DEBUG_STACK_RING
 	verify_stack_ring_consistency();
 #endif
@@ -1876,7 +1908,6 @@ void CMD_DefaultLayers(F_CMD_ARGS)
 			Scr.BottomLayer = i;
 		}
 	}
-
 	def = PeekToken(action, &action);
 	if (def)
 	{
@@ -1892,7 +1923,6 @@ void CMD_DefaultLayers(F_CMD_ARGS)
 			Scr.DefaultLayer = i;
 		}
 	}
-
 	top = PeekToken(action, &action);
 	if (top)
 	{
@@ -1908,7 +1938,6 @@ void CMD_DefaultLayers(F_CMD_ARGS)
 			Scr.TopLayer = i;
 		}
 	}
-
 #ifdef DEBUG_STACK_RING
 	verify_stack_ring_consistency();
 #endif
