@@ -255,6 +255,7 @@ static void unmap_window(FvwmWindow *t)
 	if (ret)
 	{
 		XSelectInput(dpy, FW_W(t), eventMask);
+		XFlush(dpy);
 	}
 
 	return;
@@ -317,6 +318,7 @@ static void map_window(FvwmWindow *t)
 	if (ret)
 	{
 		XSelectInput(dpy, FW_W(t), eventMask);
+		XFlush(dpy);
 	}
 
 	return;
@@ -1129,7 +1131,7 @@ void MoveViewport(int newx, int newy, Bool grab)
 		 * of the stacking order up, to minimize the expose-redraw
 		 * overhead. Windows that will be moving into view will be
 		 * moved top down, for the same reason. Use the new
-		 * stacking-order chain, rather than the old last-focussed
+		 * stacking-order chain, rather than the old last-focused
 		 * chain.
 		 *
 		 * domivogt (29-Nov-1999): It's faster to first map windows
@@ -1771,6 +1773,7 @@ void CMD_EdgeThickness(F_CMD_ARGS)
 void CMD_EdgeScroll(F_CMD_ARGS)
 {
 	int val1, val2, val1_unit, val2_unit, n;
+	char *token;
 
 	n = GetTwoArguments(action, &val1, &val2, &val1_unit, &val2_unit);
 	if (n != 2)
@@ -1785,7 +1788,7 @@ void CMD_EdgeScroll(F_CMD_ARGS)
 	 * if edgescroll >1000 and <100000
 	 * wrap at edges of desktop (a "spherical" desktop)
 	 */
-	if (val1 >= 1000)
+	if (val1 >= 1000 && val1_unit != 100)
 	{
 		val1 /= 1000;
 		Scr.flags.do_edge_wrap_x = 1;
@@ -1794,7 +1797,7 @@ void CMD_EdgeScroll(F_CMD_ARGS)
 	{
 		Scr.flags.do_edge_wrap_x = 0;
 	}
-	if (val2 >= 1000)
+	if (val2 >= 1000 && val2_unit != 100)
 	{
 		val2 /= 1000;
 		Scr.flags.do_edge_wrap_y = 1;
@@ -1804,6 +1807,26 @@ void CMD_EdgeScroll(F_CMD_ARGS)
 		Scr.flags.do_edge_wrap_y = 0;
 	}
 
+	action=SkipNTokens(action,2);
+	token = PeekToken(action, NULL);
+
+	if (token)
+	{
+		if (StrEquals(token, "wrap"))
+		{
+			Scr.flags.do_edge_wrap_x = 1;
+			Scr.flags.do_edge_wrap_y = 1;
+		}
+		else if (StrEquals(token, "wrapx"))
+		{
+			Scr.flags.do_edge_wrap_x = 1;
+		}
+		else if (StrEquals(token, "wrapy"))
+		{
+			Scr.flags.do_edge_wrap_y = 1;
+		}
+	}
+	
 	Scr.EdgeScrollX = val1 * val1_unit / 100;
 	Scr.EdgeScrollY = val2 * val2_unit / 100;
 
