@@ -161,6 +161,12 @@
 	(fw)->flags.common.s.do_ewmh_ignore_state_hints = !!(x)
 #define SETM_DO_EWMH_IGNORE_STATE_HINTS(fw,x) \
 	(fw)->flag_mask.common.s.do_ewmh_ignore_state_hints = !!(x)
+#define DO_EWMH_IGNORE_WINDOW_TYPE(fw) \
+	((fw)->flags.common.s.do_ewmh_ignore_window_type)
+#define SET_DO_EWMH_IGNORE_WINDOW_TYPE(fw,x) \
+	(fw)->flags.common.s.do_ewmh_ignore_window_type = !!(x)
+#define SETM_DO_EWMH_IGNORE_WINDOW_TYPE(fw,x) \
+	(fw)->flag_mask.common.s.do_ewmh_ignore_window_type = !!(x)
 #define EWMH_MAXIMIZE_MODE(fw) \
 	((fw)->flags.common.s.ewmh_maximize_mode)
 #define SET_EWMH_MAXIMIZE_MODE(fw,x) \
@@ -428,12 +434,6 @@
 	(fw)->flags.is_pixmap_ours = !!(x)
 #define SETM_PIXMAP_OURS(fw,x) \
 	(fw)->flag_mask.is_pixmap_ours = !!(x)
-#define IS_PLACED_WB3(fw) \
-	((fw)->flags.is_placed_wb3)
-#define SET_PLACED_WB3(fw,x) \
-	(fw)->flags.is_placed_wb3 = !!(x)
-#define SETM_PLACED_WB3(fw,x) \
-	(fw)->flag_mask.is_placed_wb3 = !!(x)
 #define IS_PLACED_BY_FVWM(fw) \
 	((fw)->flags.is_placed_by_fvwm)
 #define SET_PLACED_BY_FVWM(fw,x) \
