@@ -157,14 +157,6 @@ void SendText(int *fd, const char *message, unsigned long window);
 /** Compatibility **/
 #define SendInfo SendText
 
-/*
- *
- * SendFinishedStartupNotification - informs fvwm that the module has
- * finished its startup procedures and is fully operational now.
- *
- */
-void SendFinishedStartupNotification(int *fd);
-
 /*
  *
  * SendUnlockNotification - informs fvwm that the module has
@@ -243,6 +235,8 @@ typedef struct
 {
 	/* module name */
 	char* name;
+	/* length of the module name */
+	int namelen;
 	/* file descriptor to send info back to FVWM */
 	int to_fvwm;
 	/* file descriptor to read packets from FVWM */
