@@ -1191,7 +1191,7 @@ FvwmPicture *PGraphicsCreateTiledPicture(
 	return q;
 }
 
-Pixmap PGraphicsCreateTransprency(
+Pixmap PGraphicsCreateTransparency(
 	Display *dpy, Window win, FvwmRenderAttributes *fra, GC gc,
 	int x, int y, int width, int height, Bool parent_relative)
 {
@@ -1212,7 +1212,7 @@ Pixmap PGraphicsCreateTransprency(
 
 	if (parent_relative)
 	{
-		/* this block is not usefull if backing store ... */
+		/* this block is not useful if backing store ... */
 		if (!XGetGeometry(
 			dpy, win, &root, (int *)&junk, (int *)&junk,
 			(unsigned int *)&sw, (unsigned int *)&sh,
@@ -1325,7 +1325,7 @@ void PGraphicsTintRectangle(
 		fra.tint = tint;
 		fra.tint_percent = tint_percent;
 		fra.mask = FRAM_DEST_IS_A_WINDOW | FRAM_HAVE_TINT;
-		p = PGraphicsCreateTransprency(
+		p = PGraphicsCreateTransparency(
 			dpy, dest, &fra, gc, dest_x, dest_y, dest_w, dest_h,
 			False);
 		if (p)
@@ -1338,7 +1338,7 @@ void PGraphicsTintRectangle(
 	}
 }
 
-#if 0 /* humm... maybe usefull one day with menus */
+#if 0 /* humm... maybe useful one day with menus */
 Pixmap PGraphicsCreateTranslucent(
 	Display *dpy, Window win, FvwmRenderAttributes *fra, GC gc,
 	int x, int y, int width, int height)
