@@ -1,9 +1,6 @@
 /* -*-c-*- */
 #include <unistd.h>
-#include <stdlib.h>
 #include <stdio.h>
-#include <sys/stat.h>
-#include <fcntl.h>
 #include <sys/types.h>
 #include "libs/ftime.h"
 #include <sys/wait.h>
@@ -18,6 +15,7 @@
 #include <libs/fvwmlib.h>
 #include <fvwm/fvwm.h>
 #include <libs/vpacket.h>
+#include <libs/fvwm_sys_stat.h>
 
 #ifndef HAVE_STRERROR
 extern char *sys_errlist[];
@@ -35,3 +33,6 @@ extern char *sys_errlist[];
 #ifndef HAVE_MKFIFO
 #define mkfifo(path, mode) ((errno = ENOSYS) - ENOSYS - 1)
 #endif
+
+
+char * fifos_get_default_name();
