@@ -10,7 +10,6 @@
 #endif
 
 #include <unistd.h>
-#include <stdlib.h>
 #include <stdio.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -22,6 +21,7 @@
 
 #include <libs/fvwmlib.h>
 #include <libs/Module.h>
+#include "libs/fvwmsignal.h"
 
 #define S_NAME  "/.FvwmConsole-Socket"
 /* Prompts for readline support */
@@ -34,9 +34,6 @@
 /* #define M_PASS M_ERROR */
 #define M_PASS M_ERROR
 
-/* number of default arguments when invoked from fvwm */
-#define FARGS 6
-
 #define XTERM "xterm"
 
 /* message to client */
