@@ -22,7 +22,7 @@
 static   char cmd[MAX_COMMAND_SIZE];
 
 /* no readline - starts here */
-char *getline() {
+char *get_line() {
   if( fgets(cmd,MAX_COMMAND_SIZE,stdin) == NULL  ) {
 	return(NULL);
   }
@@ -39,7 +39,7 @@ static char *line = (char *)NULL;
 static int done_init = 0;
 static char *h_file;
 
-char *getline(void)
+char *get_line(void)
 {
     char *prompt;
     int len;
