@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -13,14 +14,14 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "config.h"
+
 #include "Tools.h"
 #include "libs/ftime.h"
 
-/******************************************************/
-/******************************************************/
-/* Fonction pour PopupMenu / function for PopupMenu   */
-/******************************************************/
-/******************************************************/
+/*
+ * Fonction pour PopupMenu / function for PopupMenu
+ */
 
 void InitPopupMenu(struct XObj *xobj)
 {
@@ -29,7 +30,8 @@ void InitPopupMenu(struct XObj *xobj)
   int i;
   char *str;
 
-  /* Enregistrement des couleurs et de la police / set the colors and the font */
+  /* Enregistrement des couleurs et de la police / set the colors and the font
+   */
   if (xobj->colorset >= 0) {
     xobj->TabColor[fore] = Colorset[xobj->colorset].fg;
     xobj->TabColor[back] = Colorset[xobj->colorset].bg;
