@@ -1,20 +1,4 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
-
-#include "config.h"
-
+/* -*-c-*- */
 #include "libs/fvwmlib.h"
 #include "libs/Module.h"
 #include "libs/Picture.h"
@@ -23,6 +7,7 @@
 #include "libs/Colorset.h"
 #include "libs/Flocale.h"
 #include "libs/Rectangles.h"
+#include "libs/fsm.h"
 
 #include <stdio.h>
 #include <signal.h>
@@ -119,7 +104,7 @@ typedef struct                  /* Type pour la gestion X */
   int colorset;
   char *font;                   /* Police utilisee */
   char *icon;                   /* Icone pour l'application iconisee */
-  Bool usegettext;              /* Utilisation de gettext? */       
+  Bool usegettext;              /* Utilisation de gettext? */
   char *localepath;             /* path pour gettext */
   Bloc *periodictasks;          /* Tableau de taches periodiques */
   Bloc *initbloc;               /* Bloc d'initalisation */
@@ -181,6 +166,7 @@ typedef struct
   time_t BeginTime;
   char *TabArg[20];
   Bool swallowed;
+  Window swallower_win;
 } X11base ;
 
 typedef struct
