@@ -2,7 +2,6 @@
 #include "config.h"
 
 #include <stdio.h>
-#include <stdlib.h>
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -352,8 +351,9 @@ int main(int argc, char **argv)
 						hints.win_gravity =
 							SouthWestGravity;
 					}
-					hints.flags |= PPosition|PWinGravity;
+					hints.flags |= PWinGravity;
 				}
+				hints.flags |= PPosition;
 			}
 		}
 		else if (strcasecmp(argv[i], "--us-geometry") == 0)
